:orphan:

Explanations
============

Explanation of how the library works and why it works that way.

.. toctree::
    :caption: Explanations

    explanations/technical-terms
    explanations/why-stack-frames
    explanations/why-squash-can-change-path
